@@ -64,6 +64,7 @@ from ansible.module_utils._text import to_bytes, to_native, to_text
 from ansible.module_utils.six.moves import xrange
 from ansible.plugins.connection import ConnectionBase
 from ansible.utils.display import Display
+from botocore.client import Config
 
 URL_TTL = 3600
 CHUNK_SIZE = 1024
@@ -234,7 +235,9 @@ class Connection(ConnectionBase):
         instance_meta = self._get_instance_meta()
         self.instance_id = instance_meta["instance"]
 
-        self._s3_client = self._get_boto_client("s3")
+        self._s3_client = self._get_boto_client("s3",
+                                                config=Config(signature_version='s3v4')
+                                                )
         self._ssm_client = self._get_boto_client("ssm", region=instance_meta["region"])
 
         display.vvv(
@@ -338,11 +341,11 @@ class Connection(ConnectionBase):
 
         return (self._process.returncode, stdout, self._flush_stderr())
 
-    def _get_boto_client(self, service, region=None):
+    def _get_boto_client(self, service, region=None, config=None):
         return boto3.Session(
             profile_name=self.get_option("profile"),
             region_name=region or self.get_option("region"),
-        ).client(service)
+        ).client(service, config=config)
 
     def _get_url(self, action, key, http_method):
         return self._s3_client.generate_presigned_url(
