@@ -2,7 +2,8 @@ from abc import ABC, abstractmethod
 from dataclasses import dataclass, field
 from typing import Optional, Sequence
 
-from sym.cli.data.global_options_base import GlobalOptionsBase
+from sym.shared.cli.data.global_options_base import GlobalOptionsBase
+
 from sym.cli.errors import CliError
 from sym.cli.helpers.ec2.client import RunningInstance
 
