@@ -2,12 +2,12 @@ from multiprocessing import Pool
 
 from sym.cli.helpers.config import Config
 from sym.cli.helpers.ssh import _preprocess_args, maybe_gen_ssh_key, ssh_key_and_config
-from sym.cli.tests.conftest import empty_saml_client, setup_context
+from sym.cli.tests.conftest import click_command, empty_saml_client, setup_context
 from sym.cli.tests.helpers.sandbox import Sandbox
 
 
 def _gen_ssh_key_fn(_i=0):
-    with setup_context():
+    with setup_context(click_command):
         maybe_gen_ssh_key(empty_saml_client())
 
 
